#[derive(
    serde::Serialize, serde::Deserialize, Copy, Clone, Debug, Eq, PartialEq, PartialOrd, Ord,
)]
pub struct FileSize(usize);

impl FileSize {
    pub const fn from_bytes(size: usize) -> Self {
        Self(size)
    }

    pub const fn from_mb(mb: usize) -> Self {
        Self(mb * 1000 * 1000)
    }

    pub const fn from_gb(gb: usize) -> Self {
        Self(gb * 1000 * 1000 * 1000)
    }

    /// Get file size as bytes
    pub fn as_bytes(&self) -> usize {
        self.0
    }

    /// Get file size as megabytes
    pub fn as_mb(&self) -> usize {
        self.0 / (1000 * 1000)
    }
}
